@@ -3,7 +3,6 @@
 # If you want to add MIME types,
 # you must add an entry in MimeHashLib and assign it to a family
 #-------------------------------------------------------
-# $Revision: 1.28 $ - $Author: eldy $ - $Date: 2011/12/30 18:23:09 $
 
 
 #package AWSMIME;
@@ -115,13 +114,16 @@
 # Document
 'ai',['document','d'],
 'doc',['document','d'],
+'docx',['document','d'],
 'wmz',['document','d'],
 'rtf',['document','d'],
 'mso',['document','d'],
 'pdf',['pdf','d'],
 'frl',['pdf','d'],
 'xls',['document','d'],
+'xlsx',['document','d'],
 'ppt',['document','d'],
+'pptx',['document','d'],
 'pps',['document','d'],
 'psd',['document','d'],
 'sxw',['ooffice','d'],
